# Dérivabilité des fonctions

Une fonction \\( f : \mathbb{R} \to \mathbb{R}\\) est **dérivable** en un \\( a \in dom(f)\\) Si
\\[ 
    \lim\limits_{x \to a \\\\ x \in dom(f) \backslash\\{a\\}} \frac{f(x) - f(a)}{x - a} \text{ existe }
\\]
Dans ce cas la dérivée de f en a est la valeur de \\(\lim\limits_{x \to a} \frac{f(x) - g(x)}{x - a}\\)

> Mais ceci require [l'unicitee de la limite](./chap2.md#unicitée-de-la-limite)

Donc \\(a \in adh(dom(f) \backslash \\{a\\}) \cap dom(f) \\)

Il faut qu'il existe \\((x\_n) \subseteq dom(f) \backslash \\{a\\} \text{ tq } x\_n \to a\\) (donc que a \\(\in dom(f)\\) ne soit pas un point isolé)

## Notation

Quand la dérivée est définie, on la note 
- \\(f'(a)\\)
- \\(D\_x f(a)\\)
- \\(\partial \_x f(a)\\)

- Si \\(f, g: \mathbb{R} \to \mathbb{R}\\)
    - La **composée de f avec g** est la fonction \\((f \circ g)\\) définie par
        - \\(f \circ g: \mathbb{R} \to \mathbb{R}: x \mapsto f (\circ g)(x) = f(g(x))\\)
            - \\(dom(f \circ g) = \\{x \in \mathbb{R} \vert x\in dom(g) et g(x) \in dom(f)\\}\\)

- Dérivée de composée de fonctions
    - \\(\partial \_x (f(x)\vert \_{x = x} ) * \partial \_x g(x)\\)

## Interpretation graphique

Nous calculons donc la pente de la droite (\\(\frac{f(b) - f(a)}{b-a}\\))

Mais nous prenons des valeurs où \\(b \to a\\) donc nous avons une fonction tangeante à la fonction

- La droite **Tangeante** est la droite 
    - de la pente \\(\partial f(a)\\)
    - passant par \\((a, f(a))\\)

Une equation cartésienne serait : \\(y = f(a) + \partial f(a)\*(x-a)\\)

- ex: \\(f(x) = x ^ 3 \quad a = 1\\)
    - \\(\partial f(x) = 3x^2 \quad \partial f(a) = 3\\)

## Interpretation de l'hypothése

- pour \\(a \in dom(f) \cap adh(dom(f) \backslash \\{a\\})\\)
    - Si a \\(\notin adh(dom(f) \backslash \\{a\\})\\)
        - alors \\(\exists r > 0 \quad [a-r, a+r] \cup dom(f) = \\{a\\}\\)
            - On ne pourrait pas trouver la dérivée car pas assez de points proche de a
            - Nous évitons juste d'avoir un point isolé

## Régles de calculs

- Soient \\(f, g: \mathbb{R} \to \mathbb{R}\\) deux fonctions dérivables en a et \\(a \in dom(f) \cap dom(g) \cap adh(dom(f)\backslash \\{a\\}) \cap adh(dom(f)\backslash \\{a\\})\\)
    - Si \\(\partial (f+g)(a)\\)
        - Alors \\(\partial f(a) + \partial g(a)\\)
    - Si \\(\partial (f\*g)(a)\\)
        - Alors \\(\partial f(a) * g(a) + f(a) * \partial g(a)\\)
    - Si \\(\partial (f/g)(a)\\)
        - Alors \\(\frac{\partial f(a) * g(a) - f(a) * \partial g(a)}{(g(a))^2}\\)
    - Si \\(\partial (f\circ g)(a)\\)
        - \\(\partial f(g(a)) * \partial g(a)\\)

## Dérivés de fonctions de base

- \\(\partial \_x (k) = 0 \quad k \in \mathbb{R}\\)
- \\(\partial \_x (x^n) = n * x ^{n - 1} \quad n \in \mathbb{Z}\\)
- \\(\partial \_x (x^\alpha ) = \alpha * x ^{\alpha - 1} \quad \alpha \in \mathbb{R}\\) 
- \\(\partial \_x (cos(x)) = -sin(x) \\)
- \\(\partial \_x (sin(x)) = cos(x) \\)
- \\(\partial \_x (ln(x)) = 1/x\\)
- \\(\partial \_x (e^x) = e^x\\)

## fonctions réciproques

Une fonction réciproque est l'image d'une fonction "inverse" (retournée sur l'axe x et l'axe y)

- On appelle g la **fonction réciproque** de f et on la note \\(f ^{-1}\\) (attention, différent de \\(\frac{1}{f}\\))
    - \\(\forall x, x' \in dom(f) \quad  x \neq x \quad f(x) \neq f(x')\\) (donc f une fonction injective)
        - \\(g: \mathbb{R} \to \mathbb{R} \quad y \mapsto (x \text{ tq } f(x) = g)\\) (est bien une fonction car f est injective)
            - \\(\implies dom(g) = Im(f)\\)
    - Pour ces fonction on sait que
        - \\(\forall x dom(f) \quad g(f(x)) = x\\)
        - \\(\forall y dom(g) \quad f(g(y)) = y\\)

### Dérivée de fonctions réciproques

\\[\partial f^{-1}(y) = \frac{1}{\partial f(f^{-1}(y))}\\]

- Si \\(f: [a, b] \to \mathbb{R}\\) est injective et \\(c \in [a,b]\\) et f est dériable en c
    - Alors \\(f^{-1}\\) est dérivable en \\(f(c)\\) et \\(\partial f^{-1}(c) = \frac{1}{\partial f(c)}\\)

### Dérivée de arcsin

\\(sin(x)\\) n'est pas injective. on ne peux donc pas prendre sa réciproque

on se restrain donc à l'interval \\([\frac{-\pi}{2}; \frac{\pi}{2}] \to \mathbb{R}\\) alors sin(x) est injective et nous pouvons prendre sa réciproque

cette fonction est appelée arcsin et est la fonction réciproque de sin
nous avons également arccos qui est la fonction réciproque de cos
ainsi que arctan qui est la fonction réciproque de arctan

- donc \\(dom(arcsin) = Im(sin) = [-1, 1]\\)
- on a \\(\forall y \in [-1; 1] \quad sin(arcsin(y)) = y\\)
- on a \\(\forall x \in [\frac{-\pi}{2}; \frac{\pi}{2}] \quad arcsin(sin(x)) = x\\)

On peut dériver les 2 cotés de l'équation sur [-1;1] et nous pouvons en déduire que
\\[\partial \_x arcsin(x) = \frac{1}{\sqrt{1 - y^2}}\\]


## Minimum et Maximum de fonctions

**Rappel**: [Croissance et décroissance de fonctions](../ineq/sqrt.html#défintions)

- Si f est croissante et dérivable en \\(a \in dom(f) \cap adh(dom(f) \backslash \\{a\\})\\)
    - Alors \\(\partial f(a) \geq 0\\)


